@@ -1,10 +1,10 @@
 from __future__ import annotations
 
 import json
-from datetime import datetime
+from datetime import datetime, timezone
 from ssl import SSLContext
 from types import TracebackType
-from typing import Any, Type
+from typing import Any
 
 import jwt
 from httpx import AsyncClient
@@ -65,8 +65,8 @@ class Client:
 
     async def __aexit__(
         self,
-        et: Type[BaseException] | None,
-        ev: Type[BaseException] | None,
+        et: type[BaseException] | None,
+        ev: type[BaseException] | None,
         traceback: TracebackType | None,
     ) -> None:
         await self.aclose()
@@ -149,7 +149,9 @@ class Client:
         """
         url = f"indexes/{uid}"
         response = await self._http_requests.delete(url)
-        status = await wait_for_task(self.http_client, response.json()["taskUid"])
+        status = await wait_for_task(
+            self.http_client, response.json()["taskUid"], timeout_in_ms=100000
+        )
         if status.status == "succeeded":
             return True
         return False
@@ -185,10 +187,10 @@ class Client:
 
         Examples:
 
-            >>> from datetime import datetime, timedelta
+            >>> from datetime import datetime, timedelta, timezone
             >>> from meilisearch_python_async import Client
             >>>
-            >>> expires_at = datetime.utcnow() + timedelta(days=7)
+            >>> expires_at = datetime.now(tz=timezone.utc) + timedelta(days=7)
             >>>
             >>> async with Client("http://localhost.com", "masterKey") as client:
             >>>     token = client.generate_tenant_token(
@@ -209,7 +211,7 @@ class Client:
 
         payload["apiKeyUid"] = api_key.uid
         if expires_at:
-            if expires_at <= datetime.utcnow():
+            if expires_at <= datetime.now(tz=timezone.utc):
                 raise ValueError("expires_at must be a time in the future")
 
             payload["exp"] = int(datetime.timestamp(expires_at))
